pitchtools.NumberedInterval
===========================

.. autoclass:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval

Lineage
-------

.. graphviz::

   digraph InheritanceGraph {
       graph [background=transparent,
           color=lightslategrey,
           fontname=Arial,
           outputorder=edgesfirst,
           overlap=prism,
           penwidth=2,
           rankdir=LR,
           root="__builtin__.object",
           splines=spline,
           style="dotted, rounded"];
       node [colorscheme=pastel19,
           fontname=Arial,
           fontsize=12,
           penwidth=2,
           style="filled, rounded"];
       edge [color=lightsteelblue2,
           penwidth=2];
       subgraph cluster___builtin__ {
           graph [label=__builtin__];
           "__builtin__.object" [color=1,
               group=0,
               label=object,
               shape=box];
       }
       subgraph cluster_abctools {
           graph [label=abctools];
           "abctools.AbjadObject" [color=2,
               group=1,
               label=AbjadObject,
               shape=box];
           "abctools.AbjadObject.AbstractBase" [color=2,
               group=1,
               label=AbstractBase,
               shape=box];
           "abctools.AbjadObject.AbstractBase" -> "abctools.AbjadObject";
       }
       subgraph cluster_pitchtools {
           graph [label=pitchtools];
           "pitchtools.Interval" [color=3,
               group=2,
               label=Interval,
               shape=oval,
               style=bold];
           "pitchtools.NumberedInterval" [color=black,
               fontcolor=white,
               group=2,
               label=<<B>NumberedInterval</B>>,
               shape=box,
               style="filled, rounded"];
           "pitchtools.Interval" -> "pitchtools.NumberedInterval";
       }
       "__builtin__.object" -> "abctools.AbjadObject.AbstractBase";
       "abctools.AbjadObject" -> "pitchtools.Interval";
   }

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.cents
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.direction_number
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.direction_string
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.from_pitch_carriers
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.is_named_interval_abbreviation
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.is_named_interval_quality_abbreviation
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.number
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.numbered_interval_number
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.semitones
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.to_named_interval
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__abs__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__add__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__copy__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__eq__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__float__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__format__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__ge__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__gt__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__hash__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__int__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__le__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__lt__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__ne__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__neg__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__repr__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__str__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__sub__

Bases
-----

- :py:class:`pitchtools.Interval <abjad.tools.pitchtools.Interval.Interval>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.cents
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.direction_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.direction_string
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.numbered_interval_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.semitones
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.to_named_interval
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.from_pitch_carriers
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.is_named_interval_abbreviation
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.is_named_interval_quality_abbreviation
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__abs__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__copy__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__float__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__int__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__neg__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.__sub__
   :noindex:
